Classes
=======

.. _chapClasses:

.. automodule:: mip.callbacks
.. automodule:: mip.model

Model
-----

.. autoclass:: mip.Model
    :members:

LinExpr
-------
.. autoclass:: mip.LinExpr
    :members:

LinExprTensor
-------------
.. autoclass:: mip.LinExprTensor
    :members:

Var
---
.. autoclass:: mip.Var
    :members:

Constr
------
.. autoclass:: mip.Constr
    :members:

Column
------
.. autoclass:: mip.Column
    :members:

ConflictGraph
-------------
.. autoclass:: mip.ConflictGraph
    :members:

VarList
-------
.. autoclass:: mip.VarList
    :members:

ConstrList
----------
.. autoclass:: mip.ConstrList
    :members:

ConstrsGenerator
----------------
.. autoclass:: mip.ConstrsGenerator
    :members:

IncumbentUpdater
----------------
.. autoclass:: mip.IncumbentUpdater
    :members:

CutType
--------
.. autoclass:: mip.CutType
    :members:

CutPool
-------
.. autoclass:: mip.CutPool
    :members:

OptimizationStatus
------------------
.. autoclass:: mip.OptimizationStatus
    :members:

SearchEmphasis
--------------
.. autoclass:: mip.SearchEmphasis
    :members:

LP_Method
---------
.. autoclass:: mip.LP_Method
   :members:



ProgressLog
-----------
.. autoclass:: mip.ProgressLog
    :members:

Exceptions
-----------

.. autoclass:: mip.MipBaseException
.. autoclass:: mip.ProgrammingError
.. autoclass:: mip.InterfacingError
.. autoclass:: mip.InvalidLinExpr
.. autoclass:: mip.InvalidParameter
.. autoclass:: mip.ParameterNotAvailable
.. autoclass:: mip.InfeasibleSolution
.. autoclass:: mip.SolutionNotAvailable

Useful functions
----------------

.. autofunction:: mip.minimize
.. autofunction:: mip.maximize
.. autofunction:: mip.xsum
.. autofunction:: mip.compute_features
.. autofunction:: mip.features


